@@ -4,7 +4,7 @@
 # for the documentation.
 #
 # (C) 2002 Harald Kirsch
-# $Revision: 1.3 $, $Date: 2002/08/07 17:33:13 $
+# $Revision: 1.4 $, $Date: 2002/09/21 14:55:58 $
 ########################################################################
 
 ##
@@ -98,7 +98,7 @@ proc putFooter {thisNode url} {
 proc putStyle {} {
   style + {
     <!--
-    p {margin-left: 1cm; text-align: justify; margin-right:1cm;}
+    p {margin-left:1cm; text-align:justify; margin-right:1cm;}
     *.n {margin-left: 0px; margin-right:0px;}
     *.tab {margin-left: 1cm; margin-right: 1cm;}
     *.ttab {
@@ -108,7 +108,8 @@ proc putStyle {} {
       font-family: monospace;
       background-color: \#eeeeee;
     }
-    ul, ol {list-style-position: inside;}
+    ul, ol {list-style-position: inside; text-align:justify;
+      margin-left:5mm; margin-right:20mm;}
     acronym {font-style: oblique;}
     -->
   }
